summaryrefslogtreecommitdiff
path: root/tools/mmd/MmdDb.py
diff options
context:
space:
mode:
authorJogi Hofmüller <jogi@mur.at>2011-07-31 16:38:40 +0000
committerJogi Hofmüller <jogi@mur.at>2011-07-31 16:38:40 +0000
commite6d1c7edf7be72017877fb9f5b77229afbea29f0 (patch)
tree2c4987953d432ee8f93dde617cc77fcd2ed8453a /tools/mmd/MmdDb.py
parent- new module MmdUser.py (diff)
- have a confirmation request sent by email for registration now
* still trouble with unicode/utf-8 characters entered in form ... git-svn-id: https://svn.spreadspace.org/mur.sat@86 7de4ea59-55d0-425e-a1af-a3118ea81d4c
Diffstat (limited to 'tools/mmd/MmdDb.py')
-rw-r--r--tools/mmd/MmdDb.py9
1 files changed, 6 insertions, 3 deletions
diff --git a/tools/mmd/MmdDb.py b/tools/mmd/MmdDb.py
index 640a8ff..18a4df8 100644
--- a/tools/mmd/MmdDb.py
+++ b/tools/mmd/MmdDb.py
@@ -39,9 +39,12 @@ class Db:
self.conn.commit ()
return self.cursor.rowcount
- def userCreate (self, user_id, firstname, lastname, email, callsign, password):
- self.cursor.execute ('INSERT INTO user (id, firstname, lastname, email, callsign, password) VALUES (?,?,?,?,?,?)',
- (user_id, firstname, lastname, email, callsign, password))
+ #
+ # user related methods
+ #
+ def userCreate (self, user_id, firstname, lastname, email, callsign, password, confreg):
+ self.cursor.execute ('INSERT INTO user (id, firstname, lastname, email, callsign, password, confreg) VALUES (?,?,?,?,?,?,?)',
+ (user_id, firstname, lastname, email, callsign, password, confreg))
self.conn.commit ()
def close (self):